DefaultsTable

Type Alias DefaultsTable 

pub type DefaultsTable = (Table, String);
Load the [defaults] table from the tool’s config layers (/etc/<tool>/config.toml overridden per key by ~/.config/<tool>/config.toml). Ok(None) when there is no config dir, no file, or no table. The second tuple field describes the sources for error messages.