pub fn require_tool(name: &str, install_hint: &str) -> Result<(), String>Expand description
Check that an external tool is available in $PATH.
Runs <name> --version and returns Ok(()) if it exits
successfully, or an error message with the install hint.
For tools that use a different version probe (e.g. koji version
instead of koji --version), use require_tool_with_arg.
Example
sandogasa_cli::require_tool("fedrq", "sudo dnf install fedrq").unwrap();